const { EmbedBuilder, ButtonBuilder } = require("@discordjs/builders");
const { ApplicationCommandOptionType, ActionRowBuilder } = require("discord.js");
const { CommandType } = require("wokcommands");

module.exports = {
    // Required for slash commands
    description: "Smash Or Pass",

    // Create a legacy and slash command
    type: CommandType.SLASH,
    testOnly: true,

    options: [{
            name: "nom",
            description: "Nom du caractère",
            required: true,
            type: ApplicationCommandOptionType.String,
        },
        {
            name: "image",
            description: "Image du caractère",
            required: true,
            type: ApplicationCommandOptionType.Attachment,
        }

    ],

    // Invoked when a user runs the ping command
    callback: ({ interaction, args, guild, channel, message }) => {

        const nom = args[0]
        const image = interaction.options.get("image").attachment;

        const imageURL = image.url;


        if (!nom) {
            interaction.reply({
                content: "Veuillez fournir un nom"
            })
            return;
        }

        // verify that the image is an actual image
        if (!image) {
            interaction.reply({
                content: "Veuillez fournir une image"
            })
            return;
        }

        const imageName = image.name

        // if it's neither a png or jpg, return an error

        if (!imageName.endsWith(".png") && !imageName.endsWith(".jpg")) {
            interaction.reply({
                content: "Veuillez fournir une image png ou jpg"
            })
            return;
        }

        embedSmash = new EmbedBuilder()
            .setColor(0x00ff00)
            .setTitle(`"${nom}", Smash or Pass?`)
            .setImage(imageURL)
            .setTimestamp()

        const smashButton = new ButtonBuilder()
            .setCustomId('smash')
            .setLabel('Smash')
            .setStyle('Success')

        const passButton = new ButtonBuilder()
            .setCustomId('pass')
            .setLabel('Pass')
            .setStyle('Danger')

        const row = new ActionRowBuilder()
            .addComponents(smashButton, passButton)

        interaction.reply({
            content: "# " + nom,
            embeds: [embedSmash],
            components: [row]
        });

    },
}